breed [cells cell]
breed [rules rule]
breed [heads head]
breed [nikas nika]
undirected-link-breed [borders border]
directed-link-breed [arrows arrow]


globals [ ACCEPTING-STATE first-state second-state quint-input program-loaded? q-state rule-count rt-tape lt-tape blank-symbol corner the-head the-active-cell at-index input transition-rules rule-table-pressed? input-pressed? first-run? rules-list flat-rules data-list]
cells-own [symbol]
rules-own [current-state new-state current-symbol new-symbol new-location  rule-counter comment]
heads-own [current-state current-symbol]

to startup
 setup
end

to setup
  ca
  set input  []
  set quint-input []
  set q-state 15
  let tape patches with [pycor = -4]
  let head-patch patches with [pycor = -5 and pxcor = 0]
  set blank-symbol "_"
  let initial-state 1
  output-print  "Quintuple (x, y, x', y', d) \nGiven a current state and a current symbol (x,y)\nChange state and symbol to (x', y')\nand move tape in direction (d)\n------------------------------"
  ask head-patch [ 
    sprout-heads 1 [
      set shape "triangle" 
      set size 2 
      set current-state (word initial-state )
      set color (read-from-string current-state * 10) + 5
      
      ]
    sprout-nikas 1 [set heading 265 fd 6 set shape "circle" set color green set size .2]
    ]
  set the-head turtle 0
  
  ask tape [ sprout-cells 1 [set shape "square" set color (gray - 2 - random 2) set symbol "_" set label symbol ]]
  

  
  ;create alan turing
  ask one-of tape with [pxcor = 4] [sprout-cells 1 [set size 1.2 set shape "person" set heading 0 fd 1 set color 135 set at-index 4]]
  set rt-tape []
  set lt-tape []
 
  set first-run? 1
end


to make-rule-table [#rules ]
  set corner patch (min-pxcor + 2) (max-pycor - 1)
  let i 0 ;row counter
  let j 0 ;group counter
  let k 0
  let m 0 ; for determining first-state and second state --ie the start and ending states
  
 
  
  foreach #rules [
      let q first first ?
      let col1 item 0 ?
      let col2 item 1 ?
      let col3 item 2 ?
      let cmt last first ?
      let spacer 1.5
      ask corner [
        
        sprout-rules 1 [
          set rule-counter k set k k + 1
          set heading 90 fd 10 * j               ;move to correct group position
          if i mod 5 = 0 [ make-header ]
          set heading 180 fd (2  + (i mod 5) * spacer)
          set heading 90 
          set shape "circle" 
          set size 1
          set color read-from-string q * 10 + 5
          set label q
          if m = 0 [set first-state read-from-string q ]
          if m = 1 [set second-state read-from-string q ]
          set m m + 1
        
          ;column one
          hatch-rules 1 [ 
            set rule-counter k set k k + 1
            fd 2
            set current-symbol "0"
            set new-symbol item 3 col1
            set new-location item 4 col1
            set comment item 5 col1 
            set current-state q
            set new-state item 2 col1
            set color read-from-string new-state  * 10 + 5
            set label (word new-symbol " " new-location)
            
          ]
          ;column two
           hatch-rules 1 [ 
            set rule-counter k set k k + 1
            fd 4
            set current-symbol "1"
            set new-symbol item 3 col2
            set new-location item 4 col2 
            set current-state q
            set new-state item 2 col2
            set comment item 5 col2 
            set color  read-from-string new-state * 10 + 5
            set label (word new-symbol " " new-location)
             
          ] 
           ;column three      
          hatch-rules 1 [ 
            set rule-counter k set k k + 1
            fd 6
            set current-symbol "_"
            set new-symbol item 3 col3
            set new-location item 4 col3 
            set current-state  q
            set new-state item 2 col3
            set comment item 5 col3 
            set color  read-from-string new-state  * 10 + 5
            set label (word new-symbol " " new-location)
        
          ]
          set shape "triangle"
          set size 1.5
          set comment cmt
      ]
         
      ]
      if i mod 5 = 4 [set j j + 1 ] ;make multiple tables for longer rule sets 
      set i i + 1
   ]
  initialize-head
end

to-report change [#show-tuple]
  ifelse [current-state] of the-head = (word 15) ;red
     [ report (sentence "_" "15" "X" "Done!") ]  
     [ let active-rule rules with [ current-state = [current-state] of the-head and current-symbol = [current-symbol] of the-head ]
       ask active-rule [ 
         set size 1.5 
        if #show-tuple = "yes"[ output-print (word "( " current-state ", " current-symbol " ) -- > ( "new-state ", " new-symbol ", " new-location " )")]
       ]
       report (sentence [new-symbol] of active-rule [new-state] of active-rule [new-location] of active-rule [comment] of active-rule)
     ]
end

to go
  read
  rite

  change-state-and-move
  if done? [stop]
end

to read
  set the-active-cell one-of turtles-on patch 0 -4
  ask the-head [set current-symbol (word [label] of the-active-cell) set label current-symbol] 
end 

to rite
  ask the-active-cell [set label first change "no" set symbol (word first change "no")]
  ask the-head [set label "" ] ;but we leave current-symbol set so that change procedure works
end

to change-state-and-move
  let new-q item 1 change "yes"
  let dir item 2 change "no"
  ask the-head [set current-state new-q  set color read-from-string current-state * 10 + 5]
  ask nikas [set label item 3 change "no"]
  move-tape dir
  ask rules [set size 1]
end
to clear-check
  ask turtles with [shape = "check"][die]
end 

to-report done?
  ifelse [color] of the-head = ACCEPTING-STATE 
  [
   ask patch 0 -1 [sprout 1 [set color green set shape "check" set size 4 set label "DONE"]]
   report true
  ]
  
  [report false]
end


to move-tape [#dir]
  
if  #dir = "X"[ stop ] ;exit move-tape procedure

if #dir = "R"
[
  ;add the symbol about to go off the screen to the tape list
  
  set rt-tape fput (word one-of [symbol] of cells-on patch max-pxcor -4) rt-tape 
  
  ;
  ask cells-on patch max-pxcor -4 [die] 
  ask cells [set  heading 90 fd 1 ]
  create-cells 1 [ 
      setxy min-pxcor -4 
      set shape "square"
       
      ifelse  length lt-tape > 0
         [
          set symbol last lt-tape
          set lt-tape but-last lt-tape
          set label symbol
          ifelse symbol = "1" or symbol = "0" 
             [set color gray ] 
             [set color (gray - 2 - random 2) ] 
 
         ] 
         [
           set symbol blank-symbol
           set label symbol 
           set color (gray - 2 - random 2)
    
         ]
  ]
  set at-index at-index + 1

]
 
 if #dir = "L"
[
  set lt-tape lput (word one-of [symbol] of cells-on patch min-pxcor -4) lt-tape 
  ask cells-on patch min-pxcor -4 [die] 
  ask cells [set  heading 270 fd 1 ]
  create-cells 1 [ 
      setxy max-pxcor -4 
      set shape "square"

      ifelse  length rt-tape > 0
         [
          set symbol first rt-tape
          set rt-tape but-first rt-tape 
          set label symbol
          
          ifelse symbol = "1" or symbol = "0" 
             [set color gray ] 
             [set color (gray - 2 - random 2) ] 
         ] 
         [
           set symbol blank-symbol
           set label symbol 
           set color (gray - 2 - random 2)
         ]
  ]
  
  set at-index at-index - 1
]
update-head
  ;This just allows us to hide the little figure so that he does wrap and destroy the illusion of a moving tape.
if at-index >= max-pxcor or at-index <= min-pxcor [ask cells with [pycor = -3] [ht] ]
if at-index <= max-pxcor and at-index >= min-pxcor [ask cells with [pycor = -3] [st] ]
end
 
 
;; extra stuff just to make things pretty
to initialize-head
  ask heads [ let x first-state set color x * 10 + 5 set current-state (word x ) ]
end


to change-head
  ask heads [ let x [color] of one-of sort-on [who] rules set color x set current-state (word (( x - 5 ) / 10)  ) ]
end


to load-input
 let sorted-cells sort-on [xcor] cells with [ ycor = -4 ]
 set data-list read-from-string input-symbols
 let i 0
 foreach data-list [ 
    ask item i sorted-cells [set label ? set symbol ? set color gray] 
    set i i + 1
    wait .22
  ]
  repeat max-pxcor - 2 [ move-tape "R" wait .03 ]
  update-head
end

to update-head
  set the-active-cell one-of turtles-on patch 0 -4
  ask the-head [let x (word [symbol] of the-active-cell) set label x set current-symbol x]
end


;to read-program
;  set the-active-cell one-of turtles-on patch 0 -4
;  let i 0
;  while [[size] of the-active-cell > .6  ] [ wait 1 ask rules with [ i = rule-counter] [st] move-tape "L" set the-active-cell one-of turtles-on patch 0 -4 set i i + 1 ]
;  set program-loaded? 1
;end

to make-header
      ;borders
      
      hatch 1  [ set breed turtles set heading 90 fd .75 set heading 180 fd 1 ht hatch 1 [ set heading 90 fd 8 create-border-with  myself] hatch 1 [ set heading 180 fd 8 create-border-with  myself]]
      ;header
      hatch 1 [set shape "zero" set heading 90 fd 2 set color white ]
      hatch 1 [set shape "one" set heading 90 fd 4 set color white ]
      hatch 1 [set shape "underscore" set heading 90 fd 6 set color white ]   
end 
to-report make-row-groups [#list]  ;bundles rules four to a bunch for layout on interface
  let i 0
  let grouped-list []
  set #list but-first #list  ;lose the header
  while [i < (length #list)] 
  [
    set grouped-list lput (list item i #list  item (i + 1) #list item (i + 2) #list ) grouped-list
    set i  i + 3
  ]
  
  report grouped-list
end

;-------------------------------------
to-report list-from-file [#filename]
  file-close-all
  file-open #filename
  let temp []
  while [not file-at-end? ] [ set temp lput file-read-line temp ]
  let list-of-file-values []
  foreach temp [ set list-of-file-values  lput split ? "," list-of-file-values ]
  report list-of-file-values
end

; split is a generic function to split strings remove quotes is added by the two read from string calls
  
to save-file
  file-open "johnSave.txt"
  let x butfirst list-from-file user-file
  foreach x [
    print  butlast ?
  ]
end



to-report split [ #string #sep ] ; #sep must be non-empty string
  let result [] ; return value
  let w length #sep
  loop ; exit when done
  [ let next-pos position #sep #string
    if not is-number? next-pos
    [ report reverse (fput #string result) ]
    set result fput (substring #string 0 next-pos) result
    set #string substring #string (next-pos + w) (length #string)
  ]
end

;[75 0 75 _ R]
;[75 1 1 _ X]
;[75 _ 15 _ X]
;[1 0 3 0 L]
;[1 1 3 1 L]
;[1 _ 3 _ L]
;[3 0 5 0 L]
;[3 1 5 1 L]
;[3 _ 5 _ L]
;[5 0 7 0 L]
;[5 1 7 1 L]
;[5 _ 7 _ L]
;[7 0 55 0 L]
;[7 1 55 1 L]
;[7 _ 55 _ L]
;[55 0 20 1 R]
;[55 1 30 0 R]
;[55 _ 10 _ X]
;[20 0 21 0 R]
;[20 1 21 1 R]
;[20 _ 21 _ R]
;[21 0 22 0 R]
;[21 1 22 1 R]
;[21 _ 22 _ R]
;[22 0 23 0 R]
;[22 1 23 1 R]
;[22 _ 23 _ R]
;[23 0 24 0 R]
;[23 1 24 1 R]
;[23 _ 24 _ R]
;[24 0 75 0 X]
;[24 1 75 1 X]
;[24 _ 15 _ X]
;[30 0 21 1 R]
;[30 1 31 0 R]
;[30 _ 21 1 R]
;[31 0 22 1 R]
;[31 1 32 0 R]
;[31 _ 22 1 R]
;[32 0 23 0 R]
;[32 1 10 1 R]
;[32 _ 23 _ R]
;[10 0 10 0 X]
;[10 1 10 1 X]
;[10 _ 10 _ X]
@#$#@#$#@
GRAPHICS-WINDOW
225
55
1272
375
30
8
17.0
1
12
1
1
1
0
1
1
1
-30
30
-8
8
0
0
1
ticks
30.0

BUTTON
15
395
160
450
Reset
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
1148
330
1253
363
Tape right  >>
move-tape \"R\"
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
244
327
356
360
<<  Tape left
move-tape \"L\"
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

TEXTBOX
10
10
385
35
Programmable Turing Machine
18
0.0
1

TEXTBOX
25
35
335
61
Load rules from a spreadsheet/csv file.
12
0.0
1

BUTTON
675
335
815
368
Change State of Head
change-head
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

OUTPUT
240
700
1280
805
12

BUTTON
10
105
147
138
Import Rule Table
setup\n;show make-row-groups list-from-file user-file\nmake-rule-table make-row-groups list-from-file user-file\n
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

INPUTBOX
10
240
205
300
input-symbols
[ 1 1 1 \"_\" 1 1 1]
1
0
String

BUTTON
12
190
147
223
Load Input
load-input
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
15
350
78
383
NIL
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
95
350
158
383
NIL
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

MONITOR
700
380
792
425
Current State
[current-state] of the-head
17
1
11

TEXTBOX
15
70
185
101
1) Load CSV Rule Table
14
0.0
1

TEXTBOX
15
160
195
191
2) Load Input (1, 0, or  \"_\") 
14
0.0
1

TEXTBOX
15
320
165
338
3) Step through Rules
14
0.0
1

@#$#@#$#@
## WHAT IS IT?
In 1936 Alan Turing published a paper describing some fundamental limits to logic and  mathematics. In order to build his argument, he needed to create a rigorous and formal defintion of an algorithm.  An algorithm is the familiar, stepwise process that we take when we solve math problems, build proofs and use deductive logic. Turing was especially interested in whether algorithms reached a definite conclusion or whether they continued endlessly. 


In order to establish that some well defined questions are beyond the reach of a conclusive algorithm, Turing created a paper and pencil "machine".  Turing's hypothetical machine had an infinite tape, a head that reads and write to the tape, and a mechanism to move the tape right or left. The head could be in one of multiple states and the tape held various symbols from a small library of possible symbols. At each step The state of the head AND the particular symbol under the head at that point in time are used to look up a particular transition rule that instructs the head to write a new (or the keep the same) symbol, change (or remain in the same) state, and move the tape right or left. We can say this more compactly:  (q, sym) --> (q', sym', dir) q is the current state, sym is the current symbol. q', the new state, sym' the new symbol, and dir the direction to move the tape. It is clear from this that each logical step can be represented as a group (tuple) of five elements: A head state possibly changing to at new state, a symbol on the tape possibly changing to a new symbol and the potential shift in environment (the tape). 

These simple steps are the essense of computation and, as we have seen in the decades since Turing, a great deal can be accomplished with these steps. In fact, all of conventional mathematics can be produced from the variation, combination and accumulation of these tiny pieces of logic. But, almost ironically, this was not Turing's objective in his 1936 paper. He was motivated to demonstrate what this mechanical process COULLDN'T achieve. 

## HOW TO USE IT
This Model imports a csv file from the same directory as the model. The imported file needs to be a CSV file with a header row and four columns (see/modify example.csv).

It is crucial that the csv file have exactly one header row, 4 columns, and four rows for each state. The first row of each group of four is the number of the state (numbers ending in 0 will be black and not visible--use state numbers ending in 5, 6 or 7). Comments are recommended and should be placed in the fourth column.
The second row in each group of 4 is represents the state when head is reading a 0, the thrid, when head is reading a 1, and the fourth, reading a blank or underscore.


## THE LARGER CONTEXT

Turing paper was motivated by his interest in demonstrating the limits of what could be computed by the step-wise method of an algorithm. 

## THINGS TO TRY

Try to create a program that:

-- turns 1's into 0's
-- adds two binary numbers
-- converts binary numbers to unary numbers
-- add two unary numbers
-- try creating a program in as few lines as possible, then again, in as many lines         (with each step contributing miinutely to the solution)
-- build an MP3 player (theoretically possible, but unlikely to play songs in real-time)



## NETLOGO FEATURES

This model uses custom turtles for the table header, turles and links as arrows and labels. It also make extensive use of lists. There are no sophisticated programmming techniques employed. 



## RELATED MODELS

This model series includes four NetLogo models: 
-- Simple Turing Machine--this model
        An introduction to the basic parts/terminology of the Turing machine)
-- Universal Turing Maching
	Illustration of a machine that accepts as input both program and data)
--A Turing Machine that accepts input from a CSV file
	This is the model to use to develop programs that run on the Turing machine
--The Halting Problem
	Turing's proof  of the impossibility of proving that mathematically truths are   reachable within a given system of logic.

## CREDITS AND REFERENCES
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

check
false
0
Polygon -7500403 true true 55 138 22 155 53 196 72 232 91 288 111 272 136 258 147 220 167 174 208 113 280 24 257 7 192 78 151 138 106 213 87 182

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

hash
false
0
Polygon -7500403 true true 135 45 165 45 120 270 90 270
Polygon -7500403 true true 195 45 225 45 180 270 150 270
Rectangle -7500403 true true 75 105 240 120
Rectangle -7500403 true true 75 180 225 195

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

one
false
2
Rectangle -7500403 false false 135 45 150 270
Rectangle -955883 false true 135 45 150 270
Rectangle -7500403 false false 120 45 135 60
Rectangle -955883 false true 105 255 180 270
Line -7500403 false 135 60 150 60
Rectangle -955883 true true 135 45 150 270
Rectangle -955883 true true 120 45 150 60
Rectangle -955883 true true 105 255 180 270
Rectangle -955883 true true 120 60 135 75
Rectangle -955883 true true 105 60 120 75
Rectangle -955883 true true 90 240 195 270
Circle -16777216 true false 180 225 30
Circle -16777216 true false 75 225 30
Rectangle -955883 true true 120 45 105 60
Rectangle -955883 true true 105 45 120 75
Rectangle -955883 true true 90 45 105 75
Circle -16777216 true false 75 30 30

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
0
Rectangle -7500403 true true 151 225 180 285
Rectangle -7500403 true true 47 225 75 285
Rectangle -7500403 true true 15 75 210 225
Circle -7500403 true true 135 75 150
Circle -16777216 true false 165 76 116

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

two
false
0
Circle -7500403 true true 75 15 150
Polygon -7500403 true true 90 60 150 30 150 45 105 75 90 60 150 30
Rectangle -7500403 true true 150 30 150 45
Polygon -7500403 true true 225 75 225 135 210 135 210 90 225 75
Polygon -7500403 true true 225 135 150 195 150 180
Polygon -7500403 true true 210 135 150 180 225 135
Polygon -7500403 true true 150 180 90 255 120 255 150 195
Polygon -7500403 true true 105 255 225 255 225 240 120 240
Polygon -7500403 true true 150 30 210 45 225 75 210 90 195 60 150 45
Polygon -7500403 true true 135 240 225 135 150 195 120 240 135 240
Polygon -7500403 true true 210 135 210 90 180 150
Polygon -7500403 true true 150 45 120 60 195 60 150 45
Rectangle -7500403 true true 120 225 240 255
Polygon -7500403 true true 195 135 150 180 210 135
Polygon -7500403 true true 105 75 90 90 75 75 90 60
Polygon -7500403 true true 90 90 105 90 105 75
Rectangle -7500403 true true 90 60 210 120
Circle -7500403 true true 105 75 30
Circle -16777216 true false 150 90 30
Circle -16777216 true false 108 63 85
Polygon -16777216 true false 120 120 75 120 120 180 165 165 195 105
Polygon -7500403 true true 135 195 90 225 90 255
Rectangle -7500403 true true 75 225 105 255

underscore
false
0
Rectangle -7500403 true true 0 225 300 270

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

zero
false
0
Circle -7500403 true true 16 16 268
Rectangle -16777216 true false 0 0 30 315
Rectangle -16777216 true false 270 0 330 300
Rectangle -16777216 true false 105 105 195 195
Circle -16777216 true false 89 44 122
Circle -16777216 true false 90 135 120
Rectangle -16777216 true false 90 120 210 195

@#$#@#$#@
NetLogo 5.0.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Polygon -7500403 true true 150 0 105 75 195 75 150 0

arrow
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 0 105 75
Line -7500403 true 150 0 195 75
Line -7500403 true 105 75 195 75
Polygon -7500403 true true 150 0 105 75 195 75

@#$#@#$#@
1
@#$#@#$#@
