
breed [cells cell]
breed [rules rule]
breed [heads head]
undirected-link-breed [borders border]
directed-link-breed [arrows arrow]


globals [rt-tape lt-tape blank-symbol corner the-head the-active-cell at-index input transition-rules rule-table-pressed? input-pressed? move-sound sound-count step-count]
cells-own [symbol]
rules-own [current-state new-state current-symbol new-symbol new-location]
heads-own [current-state current-symbol former-state]
turtles-own [class]

to startup
 setup
 set labels? true
end
to setup
  ca
 
  let tape patches with [pycor = -4]
  let head-patch patches with [pycor = -5 and pxcor = 0]
  set blank-symbol "_"
  let initial-state blue
  
  ask head-patch [
    sprout-heads 1 [
      set shape "triangle" 
      set size 2 
      set current-state initial-state 

      set color current-state show-labels
      
      ]
    
    ]
  set the-head turtle 0
  
  ask tape [ sprout-cells 1 [set shape "cell" set color (gray - 2 - random 2) set symbol "_" set label symbol ]]
  set step-count 0

  
  ;create alan turing
  ;ask one-of tape with [pxcor = 4] [sprout-cells 1 [set class "label" set size 1.2 set shape "person" set heading 0 fd 1 set color 133 set at-index 4]]
  set rt-tape []
  set lt-tape []
  show-labels
  set sound-count 0

end


to set-tape-symbols [#input]
  let sorted-cells sort-on [pxcor] cells with [pycor = -4]
  let i 0
  foreach #input [ask item i sorted-cells [set symbol ? set label ? if ? = 1 or ? = 0 [set color gray]] set i i + 1 ]
  ;foreach sort-on [pxcor] cells [ ask ? [set symbol item i #input set label symbol set i i + 1]]
 
end

to make-rule-table [#rules]
  
  set corner patch (min-pxcor + 2) (max-pycor - 1)
  let i 0 ;row counter
  let j 0 ;group counter
  foreach #rules [
      let q first ?
      let col1 item 1 ?
      let col2 item 2 ?
      let col3 item 3 ?
      let spacer 1.5
      ask corner [
        sprout-rules 1 [
          set heading 90 fd 10 * j              ;move to correct group position
          if i mod 5 = 0 [ make-header ]
          set heading 180 fd (2  + (i mod 5) * spacer)
          set heading 90 
          set shape "circle" 
          set size 1 
          set color first q 
          ;column one
          hatch-rules 1 [ 
            fd 2
            set current-symbol 0
            set new-symbol item 1 col1
            set new-location last col1 
            set current-state first q
            set new-state first col1
            set color new-state
            set label (word new-symbol " " new-location)
          ]
          ;column two
           hatch-rules 1 [ 
            fd 4
            set current-symbol 1
            set new-symbol item 1 col2
            set new-location last col2 
            set current-state first q
            set new-state first col2
            set color new-state
            set label (word new-symbol " " new-location)
          ] 
           ;column three      
          hatch-rules 1 [ 
            fd 6
            set current-symbol "_"
            set new-symbol item 1 col3
            set new-location last col3 
            set current-state first q
            set new-state first col3
            set color new-state
            set label (word new-symbol " " new-location)
          ]
          set shape "triangle"
      ]
         
      ]
      if i mod 5 = 4 [set j j + 1 ] ;make multiple tables for longer rule sets 
      set i i + 1
   ]

end

to-report change 
  ifelse [current-state] of the-head = red 
     [ report (sentence "_" red "X") ]  
     [ let active-rule rules with [ current-state = [current-state] of the-head and current-symbol = [current-symbol] of the-head ]
       ask active-rule [ set size 1.5 wait .2]
       report (sentence [new-symbol] of active-rule [new-state] of active-rule [new-location] of active-rule)
     ]
end


to go
  read
  rite
  change-state-and-move
  if done? [stop]
end

to read
  set the-active-cell one-of turtles-on patch 0 -4
  ask the-head [set current-symbol [label] of the-active-cell set label current-symbol] 
end 

to rite
  ask the-active-cell [set label first change]
  ask the-head [set label "" ] ;but we leave current symbol set so that change procedure works
end

to change-state-and-move   ;;"change" uses the the current-state and current-symbol of the-head, it returns new-state, new-symbol, and direction to move.
  let new-q item 1 change 
  let dir last change
  ask the-head [set former-state current-state set current-state new-q set color current-state]
  move-tape dir
  ask rules [set size 1]
end

to-report done?
  ifelse [color] of the-head = red 
  [
   ask patch 0 -1 [sprout 1 [set color green set shape "check" set size 4 set label "DONE" ]]
   report true
  ]
  
  [report false]
end


to move-tape [#dir]
  
set step-count step-count + 1

if  #dir = "X"[ stop ] ;exit move-tape procedure

if #dir = "R"
[
  set rt-tape fput one-of [symbol] of cells-on patch max-pxcor -4 rt-tape   ;save state to list
  ask cells-on patch max-pxcor -4 [die]                                     ;remove the about to disappear turtle
  ask cells [set  heading 90 fd 1 ]                                         ;move the tape
                                                                            ;restore stored turtle from list OR create a new blank cell if nothing stored
                                                                             
  create-cells 1 [ 
      setxy min-pxcor -4 set shape "cell"
      
      ifelse  length lt-tape > 0                                            ;if there is something in the list
         [
          set symbol last lt-tape         ;pull state from list 
          set lt-tape but-last lt-tape
          set label symbol  
          ifelse symbol != "_"
             [set color gray    ]
             [set color (gray - 2 - random 2) ]
         ] 
         [                                                                   ;if not
           set symbol blank-symbol
           set label symbol 
           set color (gray - 2 - random 2)
         ]
  ]
  set at-index at-index + 1

]
 
 if #dir = "L"
[
  set lt-tape lput one-of [symbol] of cells-on patch min-pxcor -4 lt-tape 
  ask cells-on patch min-pxcor -4 [die] 
  ask cells [set  heading 270 fd 1 ]
  create-cells 1 [ 
      setxy max-pxcor -4 
      set shape "cell"
        
      ifelse  length rt-tape > 0
         [
          set symbol first rt-tape
          set rt-tape but-first rt-tape 
          set label symbol 
          ifelse symbol != "_"
             [set color gray]
             [set color (gray - 2 - random 2) ] 
         ] 
         [
           set symbol blank-symbol
           set label symbol
           set color (gray - 2 - random 2) 
         ]
  ]

  set at-index at-index - 1

]

  ;This just allows us to hide the little figure so that he does wrap and destroy the illusion of a moving tape.
  if at-index >= max-pxcor or at-index <= min-pxcor [ask cells with [pycor = -3] [ht] ]
  if at-index <= max-pxcor and at-index >= min-pxcor [ask cells with [pycor = -3] [st] ]
 
  if step-count = 4 [ hide-labels "yes" ]
end
 
 
;; extra stuff just to make things pretty

to change-head
  if count rules = 0 [ make-rule-table  [[[blue]   [blue 0 "R"]     [blue 1 "R"]   [green "_" "L"]] [[green]  [green 1 "L"]    [green 0 "L"]  [red "_" "X"]]] ]
  ask heads [set color [color] of one-of sort-on [who] rules  set current-state color]
end

to show-labels
if labels? [
  ;ask patch 5 -1 [sprout-cells 1 [ set class "label" ht set size .1 hatch 1 [st set color black set heading 25 fd 6 set label "Alan Turing" create-arrow-to myself] ] ]
  ask patch 16 -2 [sprout 1 [set class "label" ht set size .1 hatch 1  [st set color black set heading 25 fd 6 set label "Infinite tape" create-arrow-to myself] ] ]
  ask patch -2 -5 [sprout 1 [set class "label" ht set size .1 hatch 1  [st set color black set heading 255 fd 4.5 set label "Head" create-arrow-to myself] ] ]
  if rule-table-pressed? = 1 [
    ask patch -18 3 [sprout 1 [set class "label" ht set size .1 hatch 1 [st set color black set heading 90 fd 10 set label "Transition Rule Table" create-arrow-to myself] ] ]
    ;ask patch -20 5 [sprout 1 [set class "label" ht set size .1 hatch 1 [st set color black set heading 90 fd 26 set label "Means 'change tape symbol to Blank, move tape L, change head state to Green'" create-arrow-to myself] ] ]
    ask patch -20 7 [sprout 1 [set class "label" ht set size .1 hatch 1   [st set color black set heading 90 fd 10 set label "Current symbol under Head" create-arrow-to myself] ] ]
    ask patch -28 -1 [sprout 1 [set class "label" ht set size .1 hatch 1  [st set color black set heading 180 fd 2  create-arrow-to myself hatch 1 [ set heading 90 fd 7 set label "Current state of Head"] ] ] ]
    ;ask patch -21 -1 [sprout 1 [set class "label" ht set size .1 hatch 1  [st set color black set heading 135 fd 1.5 create-arrow-to myself hatch 1 [set heading 90 fd 15.6 set label "New states, symbols and new position of Head" ]] ] ]
  ]
]
end
to hide-labels [#vis]
  ifelse #vis = "yes"
  [ask turtles with [class = "label"] [ht] ask arrows [ hide-link] ]
  [ask turtles with [class = "label"] [st] ask arrows [ show-link] ]
  
end
to make-header
      ;borders
      hatch 1  [ set breed turtles set heading 90 fd .75 set heading 180 fd 1 ht hatch 1 [ set heading 90 fd 8 create-border-with  myself] hatch 1 [ set heading 180 fd 8 create-border-with  myself]]
      ;header
      hatch 1 [set breed turtles set shape "zero" set heading 90 fd 2 set color white ]
      hatch 1 [set breed turtles set shape "one" set heading 90 fd 4 set color white ]
      hatch 1 [set breed turtles set shape "underscore" set heading 90 fd 6 set color white ]   
end 
@#$#@#$#@
GRAPHICS-WINDOW
155
70
1385
441
30
8
20.0
1
12
1
1
1
0
0
0
1
-30
30
-8
8
0
0
1
ticks
30.0

BUTTON
10
420
145
495
Reset
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
1265
390
1370
423
Tape right  >>
move-tape \"R\"
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
181
387
293
420
<<  Tape left
move-tape \"L\"
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

TEXTBOX
13
13
231
41
Simple Turing Machine
18
0.0
1

TEXTBOX
175
480
615
499
(current state, current tape symbol, new state, new symbol, direction of move) 
11
0.0
1

BUTTON
10
340
80
373
Go
ifelse  rule-table-pressed? = 0 or  input-pressed? = 0 \n[user-message \"Please provide input and a rule table.\"]\n[go]
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
85
340
145
373
Go
ifelse  rule-table-pressed? = 0 or  input-pressed? = 0 \n[user-message \"Provide input and a rule table before running the Turing machine.\"]\n[go]
T
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

BUTTON
10
115
118
148
Input
let in (list \"_\" \"_\" \"_\" \"_\" \"_\" \"_\" \"_\" \"_\" \"_\" \"_\" \"_\" \"_\" \"_\" \"_\" \"_\" \"_\" \"_\" \"_\" \"_\" 0 1 1 1 1 1 1 1 1 1 1 0 0 0 0 0 0 0 0 0 \"_\" \"_\" \"_\" \"_\" \"_\" \"_\" \"_\" \"_\" \"_\" \"_\" \"_\" \"_\" \"_\" \"_\" \"_\" \"_\" \"_\" \"_\" \"_\" \"_\" \"_\" \"_\" )\n;modify the symbols in the list create new input\n;let in (list \"#\" 1 0 )\n\nset-tape-symbols in\nset input-pressed? 1
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

TEXTBOX
14
80
164
106
1) Create input:\n
14
0.0
1

BUTTON
10
205
145
238
Rule Table
ask rules [die]\nlet rule-one []\nifelse rule-selector =  \"invert\"  ;just a switch between the two rule sets below\n[ \n  set rule-one [\n  ; current state  if sym O         if sym 1           if sym _\n    [[blue]        [blue 0 \"R\"]     [blue 1 \"R\"]       [green \"_\" \"L\"]] \n    [[green]       [green 1 \"L\"]    [green 0 \"L\"]      [red \"_\" \"X\"]] \n    [[violet]      [violet \"_\" \"L\"]   [violet \"_\" \"l\"] [violet \"_\" \"L\"]]\n   ; [[orange] [orange \"_\" \"L\"] [orange 1 \"X\"] [green 0 \"X\"]]\n   ]\n   set rule-table-pressed? 1\n   show-labels\n ]\n [ ; Modify the rules below to create a program that determines oddness or eveness\n \n  set rule-one [\n   [[blue] [blue 0 \"L\"]       [blue 1 \"R\"]   [green \"_\" \"L\"]] \n   [[green] [green 1 \"R\"]     [green 0 \"L\"]  [violet \"-\" \"L\"]] \n   [[yellow] [yellow 1 \"L\"]   [orange 1 \"X\"] [green 0 \"X\"]]\n   [[orange] [orange \"_\" \"L\"] [orange 1 \"X\"] [red 0 \"X\"]]\n   [[violet] [orange \"_\" \"L\"] [violet 1 \"X\"] [violet 0 \"X\"]]\n   [[124]    [124 0 \"L\"]      [124 1 \"X\"]    [violet 0 \"X\"]]\n   [[6]      [orange 1 \"L\"]   [6 1 \"X\"]      [6 0 \"X\"]]\n   [[16]     [orange 1 \"L\"]   [66 1 \"X\"]     [16 0 \"X\"]]\n   [[66]     [red 1 \"L\"]      [66 1 \"R\"]     [66 0 \"X\"]]\n   [[86]     [16 0 \"L\"]       [86 1 \"R\"]     [26 0 \"R\"]]\n   [[26]     [16 0 \"L\"]       [86 1 \"L\"]     [126 0 \"X\"]]\n   [[126]    [16 0 \"L\"]       [146 0 \"R\"]    [green 0 \"R\"]]\n   [[146]    [16 1 \"L\"]       [86 0 \"L\"]     [166 0 \"X\"]]\n   [[166]    [16 1 \"L\"]       [186 0 \"L\"]    [red 0 \"X\"]]\n   [[186]    [red 1 \"X\"]      [red 0 \"X\"]    [red \"_\" \"X\"]]\n   \n ]\n ]\n \n \n make-rule-table rule-one\n set rule-table-pressed? 1\n
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

TEXTBOX
14
100
164
118
(Right-click to edit)
11
0.0
1

TEXTBOX
10
165
160
190
2) Create Rule Set
14
0.0
1

TEXTBOX
10
185
160
203
(Right-click to edit)
11
0.0
1

TEXTBOX
10
315
160
333
3) Execute Program
14
0.0
1

SWITCH
1270
515
1375
548
labels?
labels?
0
1
-1000

TEXTBOX
60
35
305
61
The essence of computation
12
0.0
1

BUTTON
710
395
850
428
Change State of Head
change-head
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

CHOOSER
10
245
130
290
rule-selector
rule-selector
"invert" "odd or even"
0

TEXTBOX
15
390
165
408
4) Restart
14
0.0
1

TEXTBOX
170
455
475
473
Turing's quintuple: An \"atom\" of computation.
13
0.0
1

TEXTBOX
635
455
1330
515
Example: Look up the current color (state) of the head and the value that the head is currently reading in the Rule Table. Change the tape, change the color of the head, and move the tape according to the rule in the table. A blue dot with \"1 R\" means \"change tape value to 1, change head color to blue, and move tape Right\".
13
0.0
1

BUTTON
1200
515
1267
548
Labels
hide-labels \"no\"
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL
1

@#$#@#$#@

## WHAT IS IT?
In 1936 Alan Turing published a paper describing some fundamental limits to logic and  mathematics. In order to build his argument, he needed to create a rigorous and formal defintion of an algorithm.  An algorithm is the familiar, stepwise process that we take when we solve math problems, build proofs and use deductive logic. Turing was especially interested in whether algorithms reached a definite conclusion or whether they continued endlessly. 


In order to establish that some well defined questions are beyond the reach of a conclusive algorithm, Turing created a paper and pencil "machine".  Turing's hypothetical machine had an infinite tape, a head that reads and write to the tape, and a mechanism to move the tape right or left. The head could be in one of multiple states and the tape held various symbols from a small library of possible symbols. At each step The state of the head AND the particular symbol under the head at that point in time are used to look up a particular transition rule that instructs the head to write a new (or the keep the same) symbol, change (or remain in the same) state, and move the tape right or left. We can say this more compactly:  (q, sym) --> (q', sym', dir) q is the current state, sym is the current symbol. q', the new state, sym' the new symbol, and dir the direction to move the tape. It is clear from this that each logical step can be represented as a group (tuple) of five elements: A head state possibly changing to at new state, a symbol on the tape possibly changing to a new symbol and the potential shift in environment (the tape). 

These simple steps are the essense of computation and, as we have seen in the decades since Turing, a great deal can be accomplished with these steps. In fact, all of conventional mathematics can be produced from the variation, combination and accumulation of these tiny pieces of logic. But, almost ironically, this was not Turing's objective in his 1936 paper. He was motivated to demonstrate what this mechanical process COULLDN'T achieve. 
 

## THE TURING MACHINE

This model introduces students to the parts of a Turing machine. The parts correspond to the commonsense notions of what would be required for a human to solve a mathematical calculation (or develop a proof). The state of the head can be thought of as "What am I doing now?". The symbol under the head is the "matter at hand". The tape is can be used as scratch paper to hold temporary answers as well as used to communicate the final output. The rule table holds the "rules" for a particular process. For example, adding a column of numbers has various steps that humans use to complete the task. If the columns include many numbers, there are additional steps used to "keep track of progress". 

## HOW TO USE IT

Follow the numbers: 1, 2, 3.

This model simple loads input (1), loads a transition rule table (2) and allow the user to wither step through the program or automatically run the program. Switches allow you to speed up the execution of the program and turn off the label.

It is possible (though inconvenient) to make small edits to the input or the program in order to better understand how the input and rules interact. Right click on the interface buttons to access the code the creates rules and inputs.

For more extensive programming please use the Turing CSV model.


## THE LARGER CONTEXT

Turing paper was motivated by his interest in demonstrating the limits of what could be computed by the step-wise processes familiar to anyone who has done algebra. He provided an exact, compact and formal description of computation. The consequences of clearly articulating the mechanization of logical lead directly and rapidly to computing devices based on solid theory. 

## THINGS TO TRY

Edit the Rule Table button (right click) modify the code to create a program that determines whether a given string of 1's is odd or even. You may also what to edit the "input" button to change the initial input.



## NETLOGO FEATURES

This model uses custom turtles for the table header, turles and links as arrows and labels. It also make extensive use of lists. There are no sophisticated programmming techniques employed. 



## RELATED MODELS

This model series includes four NetLogo models: 
-- Simple Turing Machine--this model
        An introduction to the basic parts/terminology of the Turing machine)
-- Universal Turing Maching
	Illustration of a machine that accepts as input both program and data)
--A Turing Machine that accepts input from a CSV file
	This is the model to use to develop programs that run on the Turing machine
--The Halting Problem
	Turing's proof  of the impossibility of proving that mathematically truths are   reachable within a given system of logic.

## CREDITS AND REFERENCES
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

cell
false
15
Circle -16777216 true false 3 3 85
Circle -16777216 true false 213 3 85
Circle -16777216 true false 213 213 85
Circle -16777216 true false 3 213 85
Rectangle -16777216 true false 0 45 30 255
Rectangle -16777216 true false 270 45 300 255
Rectangle -16777216 true false 45 0 255 45
Rectangle -16777216 true false 45 255 255 300
Circle -16777216 true false 135 165 90
Circle -1 true true 30 45 90
Circle -1 true true 180 45 90
Circle -1 true true 180 165 90
Rectangle -1 true true 75 45 225 225
Rectangle -1 true true 75 210 225 255
Rectangle -16777216 true false 30 90 45 210
Circle -1 true true 30 165 90
Rectangle -1 true true 30 90 270 210

check
false
0
Polygon -7500403 true true 55 138 22 155 53 196 72 232 91 288 111 272 136 258 147 220 167 174 208 113 280 24 257 7 192 78 151 138 106 213 87 182

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

hash
false
0
Polygon -7500403 true true 135 45 165 45 120 270 90 270
Polygon -7500403 true true 195 45 225 45 180 270 150 270
Rectangle -7500403 true true 75 105 240 120
Rectangle -7500403 true true 75 180 225 195

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

one
false
2
Rectangle -7500403 false false 135 45 150 270
Rectangle -955883 false true 135 45 150 270
Rectangle -7500403 false false 120 45 135 60
Rectangle -955883 false true 105 255 180 270
Line -7500403 false 135 60 150 60
Rectangle -955883 true true 135 45 150 270
Rectangle -955883 true true 120 45 150 60
Rectangle -955883 true true 105 255 180 270
Rectangle -955883 true true 120 60 135 75
Rectangle -955883 true true 105 60 120 75
Rectangle -955883 true true 90 240 195 270
Circle -16777216 true false 180 225 30
Circle -16777216 true false 75 225 30
Rectangle -955883 true true 120 45 105 60
Rectangle -955883 true true 105 45 120 75
Rectangle -955883 true true 90 45 105 75
Circle -16777216 true false 75 30 30

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
0
Rectangle -7500403 true true 151 225 180 285
Rectangle -7500403 true true 47 225 75 285
Rectangle -7500403 true true 15 75 210 225
Circle -7500403 true true 135 75 150
Circle -16777216 true false 165 76 116

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

two
false
0
Circle -7500403 true true 75 15 150
Polygon -7500403 true true 90 60 150 30 150 45 105 75 90 60 150 30
Rectangle -7500403 true true 150 30 150 45
Polygon -7500403 true true 225 75 225 135 210 135 210 90 225 75
Polygon -7500403 true true 225 135 150 195 150 180
Polygon -7500403 true true 210 135 150 180 225 135
Polygon -7500403 true true 150 180 90 255 120 255 150 195
Polygon -7500403 true true 105 255 225 255 225 240 120 240
Polygon -7500403 true true 150 30 210 45 225 75 210 90 195 60 150 45
Polygon -7500403 true true 135 240 225 135 150 195 120 240 135 240
Polygon -7500403 true true 210 135 210 90 180 150
Polygon -7500403 true true 150 45 120 60 195 60 150 45
Rectangle -7500403 true true 120 225 240 255
Polygon -7500403 true true 195 135 150 180 210 135
Polygon -7500403 true true 105 75 90 90 75 75 90 60
Polygon -7500403 true true 90 90 105 90 105 75
Rectangle -7500403 true true 90 60 210 120
Circle -7500403 true true 105 75 30
Circle -16777216 true false 150 90 30
Circle -16777216 true false 108 63 85
Polygon -16777216 true false 120 120 75 120 120 180 165 165 195 105
Polygon -7500403 true true 135 195 90 225 90 255
Rectangle -7500403 true true 75 225 105 255

underscore
false
0
Rectangle -7500403 true true 0 225 300 270

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

zero
false
0
Circle -7500403 true true 16 16 268
Rectangle -16777216 true false 0 0 30 315
Rectangle -16777216 true false 270 0 330 300
Rectangle -16777216 true false 105 105 195 195
Circle -16777216 true false 89 44 122
Circle -16777216 true false 90 135 120
Rectangle -16777216 true false 90 120 210 195

@#$#@#$#@
NetLogo 5.0.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Polygon -7500403 true true 150 0 105 75 195 75 150 0

arrow
0.0
-0.2 0 0.0 1.0
0.0 1 1.0 0.0
0.2 0 0.0 1.0
link direction
true
0
Line -7500403 true 150 0 105 75
Line -7500403 true 150 0 195 75
Line -7500403 true 105 75 195 75
Polygon -7500403 true true 150 0 105 75 195 75

@#$#@#$#@
1
@#$#@#$#@
